@@ -30,5 +30,5 @@ git tag -s -m "Version $version" "$tagid"
 read -p "Upload to Framagit and PyPI? (y/N) " confirm
 if [ ! "$confirm" = y ]; then "Abort"; exit 1; fi
 
-python3 -m twine upload dist/*-${version}-*
-git push "$tagid"
+python3 -m twine upload dist/*-${version}*
+git push origin "$tagid"
